# Load/install libraries
require("this.path")
require("sf")
require(tidyverse)
require(dplyr)  # function %>%

# To set the working directory where the scripts are located
setwd(here())

# Download the zipped ESRI shape file of National Jurisdiction Areas
download.file(url = "https://data.iotc.org/reference/latest/domain/admin/shapefiles/IO_NJA_AREAS_1.0.0_SHP.zip", destfile = "IO_NJA_AREAS_1.0.0_SHP.zip")

# Unzip the contents locally
unzip("IO_NJA_AREAS_1.0.0_SHP.zip")

# Read the shapefile with the sf library
IO_NJA_AREAS_SF = st_read(dsn = "IO_NJA_AREAS_1.0.0.shp")

# Remove "NJA_" from codes
IO_NJA_AREAS_SF = IO_NJA_AREAS_SF %>% mutate(CODE = gsub("NJA_", "", CODE))

# Download the zipped ESRI shape file of Country Areas
download.file(url = "https://data.iotc.org/reference/latest/domain/admin/shapefiles/COUNTRY_AREAS_1.0.0_SHP.zip", destfile = "COUNTRY_AREAS_1.0.0_SHP.zip")

# Unzip the contents locally
unzip("COUNTRY_AREAS_1.0.0_SHP.zip")

# Read the shapefile with the sf library
COUNTRY_AREAS_SF = st_read(dsn = "COUNTRY_AREAS_1.0.0.shp")

# Remove "COU_" from codes
COUNTRY_AREAS_SF = COUNTRY_AREAS_SF %>% mutate(CODE = gsub("COU_", "", CODE))

# Filter on a CPC
CPC_CODE = "TZA"
CPC_AREA_SF = COUNTRY_AREAS_SF %>% filter(CODE == CPC_CODE)
CPC_NJA_SF = IO_NJA_AREAS_SF %>% filter(CODE == CPC_CODE)

minlong = min(st_bbox(CPC_NJA_SF)$xmin, st_bbox(CPC_AREA_SF)$xmin)
maxlong = max(st_bbox(CPC_NJA_SF)$xmax, st_bbox(CPC_AREA_SF)$xmax) 
minlat  = min(st_bbox(CPC_NJA_SF)$ymin, st_bbox(CPC_AREA_SF)$ymin)
maxlat  = max(st_bbox(CPC_NJA_SF)$ymax, st_bbox(CPC_AREA_SF)$ymax)

CPC_MAP = 
  ggplot() + 
  geom_sf(data = CPC_AREA_SF, fill = "#90503F") + 
  geom_sf(data = CPC_NJA_SF, fill = "#BDD7E7", size = .5) + 
  geom_sf_text(data = CPC_AREA_SF, aes(label = gsub(" - land area", "", NAME_EN)), color = "white") + 
  scale_x_continuous(limits = c(minlong, maxlong)) + 
  scale_y_continuous(limits = c(minlat, maxlat)) + 
  labs(x = "", y = "") +
  theme_bw() + 
  theme(legend.position = "none", legend.title = element_blank()) +
  theme(panel.grid.major = element_line(color = gray(.5), linetype = "dashed", linewidth = 0.3), panel.border = element_rect(fill = NA, colour = "black", linewidth = 1.2))

ggsave(paste0(CPC_CODE, "_MAP.png"), CPC_MAP, width = 8, height = 5)
