# Load/install libraries
require("this.path")
require("sf")
require("ows4R")  #https://github.com/eblondel/ows4R
require(tidyverse)

# To set the working directory where the scripts are located
setwd(here())

# Define Geoserver Access
WFS = WFSClient$new(url = "https://www.fao.org/fishery/geoserver/wfs", serviceVersion = "1.0.0", logger = "INFO")

# Extracting Continents
CONTINENTS_SF = WFS$getFeatures("fifao:UN_CONTINENT2_new") %>% st_set_crs(4326)

# IOTC Area of Competence from FAO Geoserver
IOTC_AREA_SF = WFS$getFeatures("rfb:RFB_IOTC") %>% st_set_crs(4326)

# IOTC Main Areas from IOTC Data Reference Catalogue
download.file(url = "https://data.iotc.org/reference/latest/domain/admin/shapefiles/IOTC_MAIN_AREAS_1.0.0_SHP.zip", destfile = "IOTC_MAIN_AREAS_1.0.0_SHP.zip")

# Unzip the contents locally
unzip("IOTC_MAIN_AREAS_1.0.0_SHP.zip")

# Read the shapefile with the sf library
IOTC_MAIN_AREAS_SF = st_read(dsn = "IOTC_MAIN_AREAS_1.0.0.shp")

# IOTC Area of Competence ####
IOTC_AREA_OF_COMPETENCE_MAP = 
  ggplot() + 
  geom_sf(data = CONTINENTS_SF, fill = "lightgrey", color = "lightgrey") + 
  geom_sf(data = IOTC_MAIN_AREAS_SF, fill = "lightblue") + 
  labs(x = "", y = "") + 
  scale_x_continuous(limits = c(-17, 149)) + 
  scale_y_continuous(limits = c(-52, 69)) + 
  theme_bw() + 
  theme(legend.position = "none", legend.title = element_blank()) +
  theme(panel.grid.major = element_line(color = gray(.5), linetype = "dashed", linewidth = 0.3), panel.border = element_rect(fill = NA, colour = "black", linewidth = 1.2))

ggsave("IOTC_AREA_OF_COMPETENCE_MAP.png", IOTC_AREA_OF_COMPETENCE_MAP, width = 8, height = 5)
