# Load/install libraries
require("this.path")
require("sf")
require("ows4R")  #https://github.com/eblondel/ows4R
require(tidyverse)

# To set the working directory where the scripts are located
setwd(here())

# IOTC Data Reference Catalogue ####

## Example of National Jurisdiction Areas

# Download the zipped ESRI shape file of a spatial layer
download.file(url = "https://data.iotc.org/reference/latest/domain/admin/shapefiles/IO_NJA_AREAS_1.0.0_SHP.zip", destfile = "IO_NJA_AREAS_1.0.0_SHP.zip")

# Unzip the contents locally
unzip("IO_NJA_AREAS_1.0.0_SHP.zip")

# Read the shapefile with the sf library
NJA_AREAS_SF = st_read(dsn = "IO_NJA_AREAS_1.0.0.shp")

# Quick plot to check
plot(NJA_AREAS_SF["CODE"])

# Fisheries Data Interoperability GitHub Repository ####

# Define the WFS source
WFS = WFSClient$new(url = "https://www.fao.org/fishery/geoserver/wfs", serviceVersion = "1.0.0", logger = "INFO")

# Countries (used by FIRMS to intersect the CWP grids)
COUNTRIES_SF = WFS$getFeatures("fifao:country_bounds") %>% st_set_crs(4326)

# 5x5 grids
CWP55_ERASED_SF = WFS$getFeatures("cwp:cwp-grid-map-5deg_x_5deg_erased") %>% st_set_crs(4326)

# Simple map

# Global base map
BaseMap = 
  ggplot() +
  geom_sf(data = COUNTRIES_SF, size = .2, fill = "darkgrey", col = NA) +
  theme(panel.grid.major = element_line(color = gray(0.9), linetype = "dashed", linewidth = 0.5))

# Global map example
BaseMap +
  geom_sf(data = CWP55_ERASED_SF, aes(fill = CWP_CODE), size = .5) + 
  theme_bw() +
  labs(x = "", y = "") +
  theme(legend.position = "none", legend.title = element_blank()) +
  theme(panel.grid.major = element_line(color = gray(.5), linetype = "dashed", linewidth = 0.3), 
        panel.background = element_rect(fill = "white"))

